changeset 109083:52060ddf14aa

Improve doc for system font things. Return font regardless of use_system_font. * xsettings.c (Ffont_get_system_normal_font, Ffont_get_system_font): Improve documentation. Return font regardless of use_system_font. (syms_of_xsettings): Improve documentation for font-use-system-font.
author Jan D <jan.h.d@swipnet.se>
date Wed, 30 Jun 2010 13:16:01 +0200
parents 8dc2952aaa12
children 9e474f641740
files src/ChangeLog src/xsettings.c
diffstat 2 files changed, 14 insertions(+), 5 deletions(-) [+]
line wrap: on
line diff
--- a/src/ChangeLog	Wed Jun 30 15:56:19 2010 +0900
+++ b/src/ChangeLog	Wed Jun 30 13:16:01 2010 +0200
@@ -1,3 +1,9 @@
+2010-06-30  Jan Djärv  <jan.h.d@swipnet.se>
+
+	* xsettings.c (Ffont_get_system_normal_font, Ffont_get_system_font):
+	Improve documentation.  Return font regardless of use_system_font.
+	(syms_of_xsettings): Improve documentation for font-use-system-font.
+
 2009-06-17  Naohiro Aota  <naota@elisp.net>  (tiny change)
 
 	* xftfont.c (xftfont_open): Check font width one by one also when
--- a/src/xsettings.c	Wed Jun 30 15:56:19 2010 +0900
+++ b/src/xsettings.c	Wed Jun 30 13:16:01 2010 +0200
@@ -719,20 +719,20 @@
 DEFUN ("font-get-system-normal-font", Ffont_get_system_normal_font,
        Sfont_get_system_normal_font,
        0, 0, 0,
-       doc: /* Get the system default font. */)
+       doc: /* Get the system default application font. */)
   ()
 {
-  return current_font && use_system_font
+  return current_font
     ? make_string (current_font, strlen (current_font))
     : Qnil;
 }
 
 DEFUN ("font-get-system-font", Ffont_get_system_font, Sfont_get_system_font,
        0, 0, 0,
-       doc: /* Get the system default monospaced font. */)
+       doc: /* Get the system default fixed width font. */)
   ()
 {
-  return current_mono_font && use_system_font
+  return current_mono_font
     ? make_string (current_mono_font, strlen (current_mono_font))
     : Qnil;
 }
@@ -774,7 +774,10 @@
   defsubr (&Sfont_get_system_normal_font);
 
   DEFVAR_BOOL ("font-use-system-font", &use_system_font,
-    doc: /* *Non-nil means to use the system defined font.  */);
+    doc: /* *Non-nil means to apply the system defined font dynamically.
+When this is non-nil and the system defined fixed width font changes, we
+update frames dynamically.
+If this variable is nil, Emacs ignores system font changes.  */);
   use_system_font = 0;
 
   DEFVAR_LISP ("xft-settings", &Vxft_settings,